@@ -14,12 +14,11 @@
 #include <pthread.h>
 #include <time.h>
 #include <errno.h>
-#if defined (__DECCXX)
 #include <vector>
 #include <list>
-#else
-#include <vector.h>
-#include <list.h>
+
+#ifndef _REENTRANT
+#error you have to compile with -D_REENTRANT
 #endif
 
 #define QP_PRIO_DFL	0
@@ -36,7 +35,7 @@
 #include <qpthr/qp_sig.h>
 #include <qpthr/qp_queue.h>
 #include <qpthr/qp_timer.h>
-
+#include <qpthr/qp_misc.h>
 
 class QpInit {
     public:
